##  Choosing Currency
You can select the currency to be displayed in reports and Fact Sheets.
**Note**
Note that changing the currency does not alter the values themselves.
![Choosing Currency for the Workspace](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b79917a441014a314acefa8c6bf56_LowRes.png)
Choosing Currency for the Workspace
